Physical constants and unit conversion.

<img src="images/planck_so.png" alt="planck logo" width="85"/>


## What is it?
Planck is a simple module that allow to:

* Access physical constants values in the units of your choice
* Convert quantities expressed in a given unit to another unit

## Okube
<img src="images/okube.png" alt="okube logo" width="85"/>

Settus is one of the *kubes* developed by [Okube](https://www.okube.ai), a company dedicated to building open source frameworks, empowering businesses to build, deploy and operate highly scalable data platforms and AI models.